@@ -21,8 +21,22 @@ def get_meta(df, large_threshold=1000):
     extract the metadata from a dataframe needed to hand over to the Filter
     """
 
+    def parse_object_cat(key):
+        cat = df[key].unique()
+        if len(cat) > large_threshold:
+            return {
+                "type": "categorical",
+                "large": True,
+                "cat": []
+            }
+        return {
+            "type": "categorical",
+            "cat": cat.tolist()
+        }
+
     def parse(key, val):
         if isinstance(val, _pd.CategoricalDtype):
+            # pandas special cat var
 
             if len(val.categories) > large_threshold:
                 return {
@@ -35,19 +49,9 @@ def get_meta(df, large_threshold=1000):
                 "cat": val.categories.tolist()
             }
         elif val == dtype('O'):
+            # conventional string mixed object cat var
+            return parse_object_cat(key)
 
-            cat = df[key].unique()
-            if len(cat) > large_threshold:
-                return {
-                    "type": "categorical",
-                    "large": True,
-                    "cat": []
-                }
-
-            return {
-                "type": "categorical",
-                "cat": cat.tolist()
-            }
         elif val == dtype('bool'):
             return {
                 "type": "bool"
@@ -55,7 +59,10 @@ def get_meta(df, large_threshold=1000):
         elif "time" in str(val):
             return {"type": "temporal", **df[key].agg(["median", "min", "max"]).T.to_dict()}
         else:
-            return {"type": "numerical", **df[key].agg(["median", "min", "max"]).T.to_dict()}
+            try:
+                return {"type": "numerical", **df[key].agg(["median", "min", "max"]).T.to_dict()}
+            except:
+                return parse_object_cat(key)
 
     return {
         k: parse(k, val)
@@ -213,7 +220,7 @@ def get_plot(inputDataFrame, config, apply_parameterization=True):
                             ["x", "y", "error_x", "error_y", "dimensions",
                                 "color", "facet_col",
                                 "size", "symbol", "pattern_shape",
-                                "facet_row", "hover_name"]
+                                "facet_row", "hover_name", "lines"]
                         ] if c is not None
                         ] for b in a]
 
@@ -269,10 +276,10 @@ def get_plot(inputDataFrame, config, apply_parameterization=True):
             # if we want to force an axis as categorical
             markCatX = False
             markCatY = False
-            if "cat_x" in plotConfigData["params"]:
+            if "cat_x" in plotConfigData["params"] and plotConfigData["params"]["cat_x"]:
                 markCatX = True
                 del plotConfigData["params"]["cat_x"]
-            if "cat_y" in plotConfigData["params"]:
+            if "cat_y" in plotConfigData["params"] and plotConfigData["params"]["cat_y"]:
                 markCatY = True
                 del plotConfigData["params"]["cat_y"]
 
@@ -280,20 +287,20 @@ def get_plot(inputDataFrame, config, apply_parameterization=True):
             makeIndepX = False
             makeIndepY = False
             if plotConfigData["type"] not in ["imshow"]:
-                if "indep_x" in plotConfigData["params"]:
+                if "indep_x" in plotConfigData["params"] and plotConfigData["params"]["indep_x"]:
                     makeIndepX = True
                     del plotConfigData["params"]["indep_x"]
-                if "indep_y" in plotConfigData["params"]:
+                if "indep_y" in plotConfigData["params"] and plotConfigData["params"]["indep_y"]:
                     makeIndepY = True
                     del plotConfigData["params"]["indep_y"]
 
             # if we have reversed x and y axis
             reversedX = False
             reversedY = False
-            if "reversed_x" in plotConfigData["params"]:
+            if "reversed_x" in plotConfigData["params"] and plotConfigData["params"]["reversed_x"]:
                 reversedX = True
                 del plotConfigData["params"]["reversed_x"]
-            if "reversed_y" in plotConfigData["params"]:
+            if "reversed_y" in plotConfigData["params"] and plotConfigData["params"]["reversed_y"]:
                 reversedY = True
                 del plotConfigData["params"]["reversed_y"]
 
